@@ -82,26 +82,26 @@ using namespace WebCore;
 static SVGPaintImpl *toPaint(CSSValueImpl *val)
 {
     if (val->cssValueType() != DOM::CSSValue::CSS_SVG_VALUE) {
-        return 0;
+        return nullptr;
     }
     SVGCSSValueImpl *svgVal = static_cast<SVGCSSValueImpl *>(val);
     if (svgVal->isSVGPaint()) {
         return static_cast<SVGPaintImpl *>(svgVal);
     } else {
-        return 0;
+        return nullptr;
     }
 }
 
 static SVGColorImpl *toColor(CSSValueImpl *val)
 {
     if (val->cssValueType() != DOM::CSSValue::CSS_SVG_VALUE) {
-        return 0;
+        return nullptr;
     }
     SVGCSSValueImpl *svgVal = static_cast<SVGCSSValueImpl *>(val);
     if (svgVal->isSVGColor()) {
         return static_cast<SVGColorImpl *>(svgVal);
     } else {
-        return 0;
+        return nullptr;
     }
 }
 
@@ -156,7 +156,7 @@ static EColorInterpolation colorInterpolationForValue(DOM::CSSPrimitiveValueImpl
 
 void CSSStyleSelector::applySVGRule(int id, DOM::CSSValueImpl *value)
 {
-    CSSPrimitiveValueImpl *primitiveValue = 0;
+    CSSPrimitiveValueImpl *primitiveValue = nullptr;
     if (value->isPrimitiveValue()) {
         primitiveValue = static_cast<CSSPrimitiveValueImpl *>(value);
     }
@@ -892,7 +892,7 @@ void CSSStyleSelector::applySVGRule(int id, DOM::CSSValueImpl *value)
     default:
         // If you crash here, it's because you added a css property and are not handling it
         // in either this switch statement or the one in CSSStyleSelector::applyProperty
-        qWarning() << "unimplemented property" << id << getPropertyName(id).string();
+        qCWarning(KHTML_LOG) << "unimplemented property" << id << getPropertyName(id).string();
         return;
     }
 }
