@@ -42,20 +42,10 @@
 #include <ecma/kjs_proxy.h>
 #include <ctype.h>
 #include <assert.h>
-#include <QtCore/QVariant>
+#include <QVariant>
 #include <stdlib.h>
 
-#ifdef __GNUC__
-// The main tokenizer includes this too so we are getting two copies of the data. However, this way the code gets inlined.
-#include "kentities.c"
-#else
-// Not inlined for non-GCC compilers
-struct entity {
-    const char *name;
-    int code;
-};
-const struct entity *kde_findEntity(register const char *str, register unsigned int len);
-#endif
+#include "kentities_p.h"
 
 #define PRELOAD_DEBUG 0
 
@@ -75,7 +65,7 @@ ProspectiveTokenizer::ProspectiveTokenizer(DOM::DocumentImpl *doc)
     , m_document(doc)
 {
 #if PRELOAD_DEBUG
-    qDebug() << "CREATING PRELOAD SCANNER FOR" << m_document << m_document->URL().toDisplayString();
+    qCDebug(KHTML_LOG) << "CREATING PRELOAD SCANNER FOR" << m_document << m_document->URL().toDisplayString();
 #endif
 }
 
@@ -269,17 +259,19 @@ unsigned ProspectiveTokenizer::consumeEntity(TokenizerString &source, bool &notE
             // This is the attribute only version, generic version matches somewhat differently
             while (entityName.size() <= 8) {
                 if (cc == ';') {
-                    const entity *e = kde_findEntity(entityName.data(), entityName.size());
-                    if (e) {
+                    int code;
+                    const bool found = kde_findEntity(entityName.data(), entityName.size(), &code);
+                    if (found) {
                         source.advance();
-                        return e->code;
+                        return code;
                     }
                     break;
                 }
                 if (!(cc >= 'a' && cc <= 'z') && !(cc >= 'A' && cc <= 'Z') && !(cc >= '0' && cc <= '9')) {
-                    const entity *e = kde_findEntity(entityName.data(), entityName.size());
-                    if (e) {
-                        return e->code;
+                    int code;
+                    const bool found = kde_findEntity(entityName.data(), entityName.size(), &code);
+                    if (found) {
+                        return code;
                     }
                     break;
                 }
@@ -892,7 +884,7 @@ void ProspectiveTokenizer::emitTag()
         return;
     }
 
-    CachedObject *o = 0;
+    CachedObject *o = nullptr;
     if (tag == ID_SCRIPT) {
         o = m_document->docLoader()->requestScript(m_urlToLoad, m_document->part()->encoding());
     } else if (tag == ID_IMAGE || tag == ID_IMG) {
